@@ -3,7 +3,7 @@
 #' mpoly is the most basic function used to create objects of class
 #' mpoly.
 #' 
-#' @param x an object of class lm
+#' @param x an object
 #' @param ... additional arguments to pass to methods
 #' @return the object formated as a mpoly object.
 #' @author David Kahle \email{david.kahle@@gmail.com}
@@ -11,40 +11,44 @@
 #' @export
 #' @examples
 #' 
-#' library(plyr)
+#' library(ggplot2); theme_set(theme_classic())
+#' library(dplyr)
 #' 
 #' n <- 101
 #' s <- seq(-5, 5, length.out = n)
 #' 
+#' 
+#' 
 #' # one dimensional case
-#' df <- data.frame(x = s)
-#' df <- mutate(df, y = -x^2 + 2*x - 3 + rnorm(n, 0, 2))
-#' with(df, plot(x, y))
-#' mod <- lm(y ~ x + I(x^2), data = df)
+#' 
+#' df <- data.frame(x = seq(-5, 5, length.out = n)) %>% 
+#'   mutate(y = -x^2 + 2*x - 3 + rnorm(n, 0, 2))
+#'
+#' (mod <- lm(y ~ x + I(x^2), data = df))
 #' (p <- as.mpoly(mod))
-#' f <- as.function(p)
-#' lines(s, f(s), col = "red")
-#' 
-#' 
-#' 
-#' # one dimensional case with ggplot2
-#' library(ggplot2); theme_set(theme_bw())
-#' 
-#' qplot(x, y, data = df) 
 #' qplot(x, y, data = df) +
-#'   stat_function(fun = f, colour = "red")
+#'   stat_function(fun = as.function(p), colour = "red", size = 1)
+#'   
+#' (mod <- lm(y ~ poly(x, 2), data = df))  
+#' (p <- as.mpoly(mod))
+#' qplot(x, y, data = df) +
+#'   stat_function(fun = as.function(p), colour = "red", size = 1)
+#' 
 #' 
 #' 
 #' # two dimensional case with ggplot2
 #' 
-#' df <- expand.grid(x = s, y = s)
-#' df <- mutate(df, z = x^2 - y^2 + 2 * x*y + rnorm(n^2, 0, 3))
+#' df <- expand.grid(x = s, y = s) %>% 
+#'   mutate(df, z = x^2 - y^2 + 2 * x*y + rnorm(n^2, 0, 3))
 #' qplot(x, y, data = df, geom = "raster", fill = z)
-#' mod <- lm(z ~ x + y + I(x^2) + I(y^2) + I(x*y), data = df)
-#' p <- as.mpoly(mod)
-#' f <- as.function(p)
-#' df$fit <- apply(df[,c("x","y")], 1, f)
+#' 
+#' (mod <- lm(z ~ x + y + I(x^2) + I(y^2) + I(x*y), data = df))
+#' (mod <- lm(z ~ poly(x, y, degree = 2, raw = TRUE), data = df))
+#' (p <- as.mpoly(mod))
+#' df$fit <- apply(df[,c("x","y")], 1, as.function(p))
+#' 
 #' qplot(x, y, data = df, geom = "raster", fill = fit)
+#' 
 #' qplot(x, y, data = df, geom = "raster", fill = z - fit) # residuals
 #' 
 #' 
@@ -66,7 +70,9 @@ as.mpoly.default <- function(x, ...)
 
 #' @export  
 as.mpoly.lm <- function(x, ...){
-  coefs <- coefficients(x)
+browser()  
+  
+  coefs <- coef(x)
   coef_names <- names(coefs)
   coef_names[coef_names == "(Intercept)"] <- 1
   I_ndcs <- which(str_detect(coef_names, "I([0-9a-zA-Z]*)"))
@@ -120,3 +126,30 @@ as.mpoly.numeric <- function(x, indeterminate = "x", ...){
 }
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
