@@ -6,9 +6,9 @@
 #' @return An object of class mpolyList.
 #' @export
 #' @examples
-#' ( p1 <- mp('t^4 - x') )
-#' ( p2 <- mp('t^3 - y') )
-#' ( p3 <- mp('t^2 - z') )
+#' ( p1 <- mp("t^4 - x") )
+#' ( p2 <- mp("t^3 - y") )
+#' ( p3 <- mp("t^2 - z") )
 #' ( ms <- mpolyList(p1, p2, p3) )
 #' is.mpolyList( ms )
 #' 
@@ -19,21 +19,26 @@
 #' ps <- mp(c("x + 1", "y + 2"))
 #' is.mpolyList(ps)
 #' 
+#' 
+#' f <- function(){
+#'   a <- mp("1")
+#'   mpolyList(a)
+#' }
+#' f()
+#' 
+#' 
 mpolyList <- function(...){
 	
-  arguments <- as.list(match.call()[-1])    
-  out <- lapply(arguments, function(l) get(as.character(l)))
+  arguments <- as.list(match.call()[-1])  
+
+  out <- lapply(arguments, eval, parent.frame(1))
 
   if(is.mpoly(out)) out <- list(out)
   
-  for(k in which(sapply(arguments, is.language))){
-    out[[k]] <- eval(arguments[[k]])
+  if(!all(vapply(out, is.mpoly, logical(1)))){
+  	stop("each argument must be of class mpoly.", call. = FALSE)
   }
   
-  if(!all(sapply(out, is.mpoly))){
-  	stop('each argument must be of class mpoly.', call. = FALSE)
-  }
-  
-  class(out) <- 'mpolyList'
+  class(out) <- "mpolyList"
   out
 }
